@@ -6,23 +6,24 @@ from testit_python_commons.services.utils import Utils
 @Utils.deprecated('Use "addLinks" instead.')
 def addLink(url: str, title: str = None, type: str = None, description: str = None):
     if hasattr(TmsPluginManager.get_plugin_manager().hook, 'add_link'):
-        TmsPluginManager.get_plugin_manager().hook\
+        TmsPluginManager.get_plugin_manager().hook \
             .add_link(link={
+            "url": url,
+            "title": title,
+            "type": type,
+            "description": description})
+
+
+def addLinks(url: str = None, title: str = None, type: str = None, description: str = None,
+             links: list or tuple = None):
+    if hasattr(TmsPluginManager.get_plugin_manager().hook, 'add_link'):
+        if url:
+            TmsPluginManager.get_plugin_manager().hook \
+                .add_link(link={
                 "url": url,
                 "title": title,
                 "type": type,
                 "description": description})
-
-
-def addLinks(url: str = None, title: str = None, type: str = None, description: str = None, links: list or tuple = None):
-    if hasattr(TmsPluginManager.get_plugin_manager().hook, 'add_link'):
-        if url:
-            TmsPluginManager.get_plugin_manager().hook\
-                .add_link(link={
-                    "url": url,
-                    "title": title,
-                    "type": type,
-                    "description": description})
         elif links and (isinstance(links, list) or isinstance(links, tuple)):
             for link in links:
                 if isinstance(link, dict) and 'url' in link:
@@ -37,13 +38,13 @@ def addLinks(url: str = None, title: str = None, type: str = None, description:
 @Utils.deprecated('Use "addMessage" instead.')
 def message(test_message: str):
     if hasattr(TmsPluginManager.get_plugin_manager().hook, 'add_message'):
-        TmsPluginManager.get_plugin_manager().hook\
+        TmsPluginManager.get_plugin_manager().hook \
             .add_message(test_message=test_message)
 
 
 def addMessage(test_message: str):
     if hasattr(TmsPluginManager.get_plugin_manager().hook, 'add_message'):
-        TmsPluginManager.get_plugin_manager().hook\
+        TmsPluginManager.get_plugin_manager().hook \
             .add_message(test_message=test_message)
 
 
@@ -53,7 +54,7 @@ def attachments(*attachments_paths):
         Step.add_attachments(attachments_paths)
     else:
         if hasattr(TmsPluginManager.get_plugin_manager().hook, 'add_attachments'):
-            TmsPluginManager.get_plugin_manager().hook\
+            TmsPluginManager.get_plugin_manager().hook \
                 .add_attachments(attach_paths=attachments_paths)
 
 
@@ -75,8 +76,8 @@ def addAttachments(data, is_text: bool = False, name: str = None):
             Step.create_attachment(str(data), name)
             TmsPluginManager.get_plugin_manager().hook \
                 .create_attachment(
-                    body=str(data),
-                    name=name)
+                body=str(data),
+                name=name)
         elif hasattr(TmsPluginManager.get_plugin_manager().hook, 'add_attachments'):
             if isinstance(data, str):
                 TmsPluginManager.get_plugin_manager().hook \
